@@ -2,12 +2,14 @@ from dataclasses import dataclass
 
 from cognite.air.utils import strip_patch_from_version
 from cognite.client import CogniteClient
+from cognite.client.data_classes import Asset
 
 
 @dataclass(frozen=True)
 class AIRClientConfig:
     client: CogniteClient
     data_set_id: int
+    schedule_asset: Asset
     schedule_asset_id: int
     schedule_asset_ext_id: str
     data_fields: dict
